/*
 * Copyright 1991 Addison-Wesley Publishing Company
 *                (see the file "COPYRIGHTS" for details)
 */

/* includes */
#include <Xm/Xm.h>
#include <X11/Shell.h>

#include "StepList.h"

/* global definitions */

#define PROGRAM_CLASS "Stepper"
#define ERROR_CLASS   "StepperError"

#define NUM_ARGS 10

/* error definitions */

#define NErrCannotOpen "cannotOpen"
#define TErrMain       "Main"

/* main window creation */

static void PrintCurrent (widget, client_data, call_data)
    Widget                   widget;
    caddr_t                  client_data;
    StepListCallbackStruct  *call_data;
{
    printf ("step from %d to %d .\n", call_data->previous, call_data->current);
}

/* must be static because it is not copied in CreateStepList */
XmString      array[3];

static void CreateMainWindow (toplevel)
    Widget        toplevel;
{
    Arg           args[2];

    array[0] = XmStringCreateLtoR ("-------", XmSTRING_DEFAULT_CHARSET);
    array[1] = XmStringCreateLtoR ("hello you all", XmSTRING_DEFAULT_CHARSET);
    array[2] = XmStringCreateLtoR ("there", XmSTRING_DEFAULT_CHARSET);

    XtSetArg (args[0], XmNitems, array);
    XtSetArg (args[1], XmNitemCount, 3);
    CreateStepList (toplevel, "list", args, 2, PrintCurrent, NULL);
}


/******************************/

void main (argc, argv)
    unsigned int    argc;
    char          **argv;
{
    Display        *display;
    XtAppContext    ac;
    Arg             args[NUM_ARGS];
    Widget          toplevel;

    /* init toolkit */
    XtToolkitInitialize();
    ac = XtCreateApplicationContext();
    display = XtOpenDisplay (
                  ac,          /* application context = default */
                  NULL,        /* use DISPLAY from environment  */
                  NULL,        /* use last of argv[0] as name   */
                  PROGRAM_CLASS,
                  NULL,        /* no add'tl cmd line options    */
                  0,           /* ditto                         */
                  &argc,
                  argv);        /* use and delete std options    */

    if (display == NULL)       /* necessary !                   */
        XtErrorMsg (
            NErrCannotOpen, TErrMain,  /* resource name         */
            ERROR_CLASS,               /* resource class        */
            "cannot open display",     /* default message       */
            NULL, NULL);               /* parameters            */

    /* create application shell */
    XtSetArg (args[0], XmNallowShellResize, True);
    toplevel = XtAppCreateShell (
                   NULL,               /* use same program name */
                   PROGRAM_CLASS,      /* repeat class param    */
                   applicationShellWidgetClass,
                   display,
                   args, 1);           /* argument list         */

    /* create main window */
    CreateMainWindow (toplevel);

    /* start loop */
    XtRealizeWidget (toplevel);
    XtAppMainLoop (ac);
}

